<?php
/**
 * Copyright oceanwebguru.com 2022
 * PrestaShop is an International Registered Trademark & Property of PrestaShop SA
 *
 * NOTICE OF LICENSE
 *
 * This source file is subject to the Academic Free License version 3.0
 * that is bundled with this package in the file LICENSE.md.
 * It is also available through the world-wide-web at this URL:
 * https://opensource.org/licenses/AFL-3.0
 * If you did not receive a copy of the license and are unable to
 * obtain it through the world-wide-web, please send an email
 * to license@prestashop.com so we can send you a copy immediately.
 *
 * @author    Radadiya Ajay <aradadiya163@rest.com>
 * @copyright oceanwebguru.com 2022
 * @license   https://opensource.org/licenses/AFL-3.0 Academic Free License version 3.0
 * @version   1.0
 * oceanwebguru.com
 * Languages: EN 
 * PS version: 1.6
**/
if (!defined('_PS_VERSION_')) {
    exit;
}
class ocSideCart extends Module
{
    public function __construct()
    {
        $this->module_key = '569f2e027d806f9e0089c307af9fe4a5';
        $this->name = 'ocsidecart';
        $this->tab = 'front_office_features';
        $this->version = '1.0.1';
        $this->author = 'Ajay Radadiya';
        $this->need_instance = 0;
        $this->ps_versions_compliancy = [
            'min' => '1.6',
            'max' => _PS_VERSION_,
        ];
        $this->bootstrap = true;
        parent::__construct();
        $this->displayName = $this->l('OC Side Cart');
        $this->description = $this->l('Customer easy use side cart');
        $this->confirmUninstall = $this->l('Are you sure you want to uninstall?');
        if (!Configuration::get('MYMODULE_NAME')) {
            $this->warning = $this->l('No name provided');
        }
    }

    public function install()
    {
        if (!parent::install() or
            !$this->registerHook('displayBeforeBodyClosingTag') or
            !$this->registerHook('displayBackOfficeHeader') or
            !$this->registerHook('header')) {
            return false;
        }

        return true;
    }

    public function hookDisplayBeforeBodyClosingTag($params)
    {
        $params = $this->getParams();
        $params['OCPRODUCTDELETE_BTN'] = $this->_path . 'views/img/ocproductclosebtn.png';
        $params['OCCART_EMPTY_ICON'] = $this->_path . 'views/img/shopping-bag.png';
        $cart = $this->context->cart; // Get the current cart object
        $cart_total = $cart->getOrderTotal(true, Cart::BOTH);
        $subtotal = $cart->getOrderTotal(false, Cart::ONLY_PRODUCTS);
        $shipping_price = $cart->getTotalShippingCost(null, true, null, null, false);
        $tax_amount = $cart->getOrderTotal(true, 6);
        $item_count = $cart->nbProducts();
        $currency = $this->context->currency;
        $price_prefix = $currency->getSign();
        $occart_url = $this->context->link->getPageLink('cart');
        $ocshop_url = $this->context->link->getPageLink('index');
        $occheckout_url = $this->context->link->getPageLink('order', true , null, 'step=1');

        $params['OCPRO_CART_SUBTOTAL'] = $subtotal;
        $params['OCPRO_CART_TOTAL'] = $cart_total;
        $params['OCPRO_CART_PRODUCT_COUNT'] = $item_count;
        $params['OCPRO_CART_PRICE_PREFIX'] = $price_prefix;
        $params['OCPRO_CART_PRICE_PREFIX'] = '€';
        $params['OCPRO_CART_SHIPPING_PRICE'] = $shipping_price;
        $params['tax_amount'] = $tax_amount;
        $params['OCPRO_CART_PAGE_LINK'] = $occart_url;
        $params['OCPRO_SHOP_PAGE_LINK'] = $ocshop_url;
        $params['OCPRO_CHECKOUT_LINK'] = $occheckout_url;

        $this->context->smarty->assign($params);
        return $this->display(__FILE__, '/views/templates/front/ocside_cart.tpl');
    }

    public function hookDisplayBackOfficeHeader()
    {
        if (Tools::getValue('configure') == 'ocsidecart') {
            $this->context->controller->addCSS($this->_path . '/views/css/coloris.min.css', 'all');
            $this->context->controller->addJS($this->_path . '/views/js/coloris.min.js', 'all');
            $this->context->controller->addJS($this->_path . '/views/js/ocsidecart_admin.js', 'all');
        }
    }

    public function hookDisplayHeader()
    {
        $params = $this->getParams();
        $this->context->smarty->assign($params);
        $enabledsidecart = Configuration::get('OCSC_ENABLED');
        if ($enabledsidecart == 'yes') {
            $baseUri = Tools::getShopDomain(true, true) . __PS_BASE_URI__;
            $id_product_attribute = (int)Tools::getValue('id_product_attribute');
            $ocsidecartposition = Configuration::get('OCSC_CART_POSITION');
            $myData = array(
                'ocscajaxcontrollerlink' => $this->context->link->getModuleLink('ocsidecart', 'ocfrontsidecart',array('ajax'=>true,'action' => 'ajaxProcessMyAction')),
                'ajaxcartitemdelete' => $this->context->link->getModuleLink('ocsidecart', 'ocsidecartitemdelete',array('ajax'=>true,'action' => 'ajaxProcessDeleteitem')),
                'ajaxcartproquantityupdate' => $this->context->link->getModuleLink('ocsidecart', 'ocproquantityupdate',array('ajax'=>true,'action' => 'ajaxProcessUpdateitem')),
                'ATC_PRODUCT_ID' => (int) Tools::getValue('id_product'),
                'id_product_attribute' =>  $id_product_attribute,
                'ocsidecartposition' =>  $ocsidecartposition,
                'baseUri' => $baseUri,
            );
          /* $this->context->controller->registerJavascript(
                $this->name,
                 $this->_path . 'views/js/ocsidecart_front.js',
                array(
                    'position' => 'bottom',
                    'priority' => 150,
                    'server' => 'remote',
                    'attributes' => 'async'
                )
            );*/
            
            $this->context->controller->addJS($this->_path.'views/js/ocsidecart_front.js');
          $this->context->smarty->assign('ocscmyData', json_encode($myData));
           $cart = $this->context->cart;
        $products = $cart->getProducts();

        // Smarty ke through data ko template mein pass karein
        $this->context->smarty->assign(array(
            'cartProducts' => $products,
            'cartTotal' => $cart->getOrderTotal(true, Cart::BOTH_WITHOUT_SHIPPING)
        ));
            // print_r($this);
            // Media::addJsDef(['ocscmyData' => $myData]);
        }
        $this->context->controller->addCSS($this->_path . '/views/css/ocsidecart_front.css', 'all');
        // print_r($this->_path);
        //  exit;
    }

    public function getParams()
    {
        $params = [
            'OCSC_ENABLED',
            'OCSC_SUBTOTAL_ENABLE',
            'OCSC_SHIPPING_ENABLE',
            'OCSC_TAX_ENABLE',
            'OCSC_TOTAL_ENABLE',
            'OCSC_HEADING_TEXT',
            'OCSC_FOOTER_HEAD_TEXT',
            'OCSC_FOOTER_DESCRIPTION',
            'OCSC_FOOTER_CHECKOUT_TEXT',
            'OCSC_FOOTER_CART_TEXT',
            'OCSC_CART_POSITION',
            'OCSC_DISPLAY_CHECKOUT',
            'OCSC_DISPLAY_VIEW_CART',
            'OCSC_FOOTER_BTN_POSITION',
            'OCSC_DISPLAY_STICKY_CART',
            'OCSC_TOPBAR_BG_CLR',
            'OCSC_TOPBAR_HEADING_CLR',
            'OCSC_TOPBAR_CLOSE_BTN_CLR',
            'OCSC_CONTAINER_BG_CLR',
            'OCSC_CONTAINER_TEXT_CLR',
            'OCSC_FOOTER_BG_CLR',
            'OCSC_FOOTER_TEXT_CLR',
            'OCSC_FOOTER_CHECKOUT_BTNBG_CLR',
            'OCSC_FOOTER_CHECKOUT_BTNTEXT_CLR',
            'OCSC_FOOTER_VIEWCART_BTNBG_CLR',
            'OCSC_FOOTER_VIEWCART_BTNTEXT_CLR',
            'OCSC_STICKY_BTN_BG_CLR',
            'OCSC_STICKY_BTN_CLR',
        ];
        $params = Configuration::getMultiple($params);
        extract($params);
        $params['OCSC_ENABLED'] = ((empty($OCSC_ENABLED)) ? 'yes' : $OCSC_ENABLED);
        $params['OCSC_SUBTOTAL_ENABLE'] = ((empty($OCSC_SUBTOTAL_ENABLE)) ? 'yes' : $OCSC_SUBTOTAL_ENABLE);
        $params['OCSC_SHIPPING_ENABLE'] = ((empty($OCSC_SHIPPING_ENABLE)) ? 'yes' : $OCSC_SHIPPING_ENABLE);
        $params['OCSC_TAX_ENABLE'] = ((empty($OCSC_TAX_ENABLE)) ? 'yes' : $OCSC_TAX_ENABLE);
        $params['OCSC_TOTAL_ENABLE'] = ((empty($OCSC_TOTAL_ENABLE)) ? 'yes' : $OCSC_TOTAL_ENABLE);
        $params['OCSC_HEADING_TEXT'] = ((empty($OCSC_HEADING_TEXT)) ? 'Shopping Cart' : $OCSC_HEADING_TEXT);
        $params['OCSC_FOOTER_HEAD_TEXT'] = ((empty($OCSC_FOOTER_HEAD_TEXT)) ? 'Order Summary' : $OCSC_FOOTER_HEAD_TEXT);
        $params['OCSC_FOOTER_DESCRIPTION'] = ((empty($OCSC_FOOTER_DESCRIPTION)) ? 'Gifts Cards and Coupon Codes applied at Checkout.' : $OCSC_FOOTER_DESCRIPTION);
        $params['OCSC_FOOTER_CHECKOUT_TEXT'] = ((empty($OCSC_FOOTER_CHECKOUT_TEXT)) ? 'CHECKOUT' : $OCSC_FOOTER_CHECKOUT_TEXT);
        $params['OCSC_FOOTER_CART_TEXT'] = ((empty($OCSC_FOOTER_CART_TEXT)) ? 'VIEW CART' : $OCSC_FOOTER_CART_TEXT);
        $params['OCSC_CART_POSITION'] = ((empty($OCSC_CART_POSITION)) ? 'yes' : $OCSC_CART_POSITION);
        $params['OCSC_DISPLAY_CHECKOUT'] = ((empty($OCSC_DISPLAY_CHECKOUT)) ? 'yes' : $OCSC_DISPLAY_CHECKOUT);
        $params['OCSC_DISPLAY_VIEW_CART'] = ((empty($OCSC_DISPLAY_VIEW_CART)) ? 'yes' : $OCSC_DISPLAY_VIEW_CART);
        $params['OCSC_FOOTER_BTN_POSITION'] = ((empty($OCSC_FOOTER_BTN_POSITION)) ? 'no' : $OCSC_FOOTER_BTN_POSITION);
        $params['OCSC_DISPLAY_STICKY_CART'] = ((empty($OCSC_DISPLAY_STICKY_CART)) ? 'yes' : $OCSC_DISPLAY_STICKY_CART);
        $params['OCSC_TOPBAR_BG_CLR'] = ((empty($OCSC_TOPBAR_BG_CLR)) ? '#2ccbeb' : $OCSC_TOPBAR_BG_CLR);
        $params['OCSC_TOPBAR_HEADING_CLR'] = ((empty($OCSC_TOPBAR_HEADING_CLR)) ? '#ffffff' : $OCSC_TOPBAR_HEADING_CLR);
        $params['OCSC_TOPBAR_CLOSE_BTN_CLR'] = ((empty($OCSC_TOPBAR_CLOSE_BTN_CLR)) ? '#ffffff' : $OCSC_TOPBAR_CLOSE_BTN_CLR);
        $params['OCSC_CONTAINER_BG_CLR'] = ((empty($OCSC_CONTAINER_BG_CLR)) ? '#ffffff' : $OCSC_CONTAINER_BG_CLR);
        $params['OCSC_CONTAINER_TEXT_CLR'] = ((empty($OCSC_CONTAINER_TEXT_CLR)) ? '#000000' : $OCSC_CONTAINER_TEXT_CLR);
        $params['OCSC_FOOTER_BG_CLR'] = ((empty($OCSC_FOOTER_BG_CLR)) ? '#ffffff' : $OCSC_FOOTER_BG_CLR);
        $params['OCSC_FOOTER_TEXT_CLR'] = ((empty($OCSC_FOOTER_TEXT_CLR)) ? '#000000' : $OCSC_FOOTER_TEXT_CLR);
        $params['OCSC_FOOTER_CHECKOUT_BTNBG_CLR'] = ((empty($OCSC_FOOTER_CHECKOUT_BTNBG_CLR)) ? '#000000' : $OCSC_FOOTER_CHECKOUT_BTNBG_CLR);
        $params['OCSC_FOOTER_CHECKOUT_BTNTEXT_CLR'] = ((empty($OCSC_FOOTER_CHECKOUT_BTNTEXT_CLR)) ? '#ffffff' : $OCSC_FOOTER_CHECKOUT_BTNTEXT_CLR);
        $params['OCSC_FOOTER_VIEWCART_BTNBG_CLR'] = ((empty($OCSC_FOOTER_VIEWCART_BTNBG_CLR)) ? '#000000' : $OCSC_FOOTER_VIEWCART_BTNBG_CLR);
        $params['OCSC_FOOTER_VIEWCART_BTNTEXT_CLR'] = ((empty($OCSC_FOOTER_VIEWCART_BTNTEXT_CLR)) ? '#ffffff' : $OCSC_FOOTER_VIEWCART_BTNTEXT_CLR);
        $params['OCSC_STICKY_BTN_BG_CLR'] = ((empty($OCSC_STICKY_BTN_BG_CLR)) ? '#ff9529' : $OCSC_STICKY_BTN_BG_CLR);
        $params['OCSC_STICKY_BTN_CLR'] = ((empty($OCSC_STICKY_BTN_CLR)) ? '#ffffff' : $OCSC_STICKY_BTN_CLR);

        return $params;
    }

    public function getContent()
    {
        $output = '';
        if (Tools::isSubmit('OcsidecartsendTokenMessage')) {
            Configuration::updateValue('OCSC_ENABLED', Tools::getValue('OCSC_ENABLED'));
            Configuration::updateValue('OCSC_SUBTOTAL_ENABLE', Tools::getValue('OCSC_SUBTOTAL_ENABLE'));
            Configuration::updateValue('OCSC_SHIPPING_ENABLE', Tools::getValue('OCSC_SHIPPING_ENABLE'));
            Configuration::updateValue('OCSC_TAX_ENABLE', Tools::getValue('OCSC_TAX_ENABLE'));
            Configuration::updateValue('OCSC_TOTAL_ENABLE', Tools::getValue('OCSC_TOTAL_ENABLE'));
            Configuration::updateValue('OCSC_HEADING_TEXT', Tools::getValue('OCSC_HEADING_TEXT'));
            Configuration::updateValue('OCSC_FOOTER_HEAD_TEXT', Tools::getValue('OCSC_FOOTER_HEAD_TEXT'));
            Configuration::updateValue('OCSC_FOOTER_DESCRIPTION', Tools::getValue('OCSC_FOOTER_DESCRIPTION'));
            Configuration::updateValue('OCSC_FOOTER_CHECKOUT_TEXT', Tools::getValue('OCSC_FOOTER_CHECKOUT_TEXT'));
            Configuration::updateValue('OCSC_FOOTER_CART_TEXT', Tools::getValue('OCSC_FOOTER_CART_TEXT'));
            Configuration::updateValue('OCSC_CART_POSITION', Tools::getValue('OCSC_CART_POSITION'));
            Configuration::updateValue('OCSC_DISPLAY_CHECKOUT', Tools::getValue('OCSC_DISPLAY_CHECKOUT'));
            Configuration::updateValue('OCSC_DISPLAY_VIEW_CART', Tools::getValue('OCSC_DISPLAY_VIEW_CART'));
            Configuration::updateValue('OCSC_FOOTER_BTN_POSITION', Tools::getValue('OCSC_FOOTER_BTN_POSITION'));
            Configuration::updateValue('OCSC_DISPLAY_STICKY_CART', Tools::getValue('OCSC_DISPLAY_STICKY_CART'));
            Configuration::updateValue('OCSC_TOPBAR_BG_CLR', Tools::getValue('OCSC_TOPBAR_BG_CLR'));
            Configuration::updateValue('OCSC_TOPBAR_HEADING_CLR', Tools::getValue('OCSC_TOPBAR_HEADING_CLR'));
            Configuration::updateValue('OCSC_TOPBAR_CLOSE_BTN_CLR', Tools::getValue('OCSC_TOPBAR_CLOSE_BTN_CLR'));
            Configuration::updateValue('OCSC_CONTAINER_BG_CLR', Tools::getValue('OCSC_CONTAINER_BG_CLR'));
            Configuration::updateValue('OCSC_CONTAINER_TEXT_CLR', Tools::getValue('OCSC_CONTAINER_TEXT_CLR'));
            Configuration::updateValue('OCSC_FOOTER_BG_CLR', Tools::getValue('OCSC_FOOTER_BG_CLR'));
            Configuration::updateValue('OCSC_FOOTER_TEXT_CLR', Tools::getValue('OCSC_FOOTER_TEXT_CLR'));
            Configuration::updateValue('OCSC_FOOTER_CHECKOUT_BTNBG_CLR', Tools::getValue('OCSC_FOOTER_CHECKOUT_BTNBG_CLR'));
            Configuration::updateValue('OCSC_FOOTER_CHECKOUT_BTNTEXT_CLR', Tools::getValue('OCSC_FOOTER_CHECKOUT_BTNTEXT_CLR'));
            Configuration::updateValue('OCSC_FOOTER_VIEWCART_BTNBG_CLR', Tools::getValue('OCSC_FOOTER_VIEWCART_BTNBG_CLR'));
            Configuration::updateValue('OCSC_FOOTER_VIEWCART_BTNTEXT_CLR', Tools::getValue('OCSC_FOOTER_VIEWCART_BTNTEXT_CLR'));
            Configuration::updateValue('OCSC_STICKY_BTN_BG_CLR', Tools::getValue('OCSC_STICKY_BTN_BG_CLR'));
            Configuration::updateValue('OCSC_STICKY_BTN_CLR', Tools::getValue('OCSC_STICKY_BTN_CLR'));
            $output .= $this->displayConfirmation(
                'Settings updated.',
                [],
                'Admin.Global'
            );
        }
        if (isset($this->ps_version)) {
            $params = $this->getParams();
            $moduleAdminLink = Context::getContext()->link->getAdminLink('AdminModules', true, false, $params);
        } else {
            $comurl = '&configure=' . $this->name . '&module_name=' . $this->name;
            $moduleAdminLink = Context::getContext()->link->getAdminLink('AdminModules', true) . $comurl;
        }
        // get current page
        $currentPage = 'ocproductinquiry';
        $page = Tools::getValue('page');
        if (!empty($page)) {
            $currentPage = Tools::getValue('page');
        }
        $params = $this->getParams();
        $this->context->smarty->assign([
            'module_name' => $this->name,
            'module_version' => $this->version,
            'moduleAdminLink' => $moduleAdminLink,
            'module_display' => $this->displayName,
            'currentPage' => $currentPage,
            'ps_base_dir' => Tools::getHttpHost(true),
            'ps_version' => _PS_VERSION_,
            'isPs17' => isset($this->ps_version),
            'ocsidecart_params' => $params,
        ]);
        $output .= '';

        return $output . $this->context->smarty->fetch($this->local_path . 'views/templates/admin/ocsidecart_admin.tpl');
    }
}
